var assert  = require("assert"),
    proxy   = require("../index");


// Read initial configuration from the file.
//
// Test procedure expects to find a file 'config.json' in this folder.
// The expected file structure:
//  {
//     "baseUrl":    "example.com",            // no "http" here!
//     "defaultCredentials": {
//         "user":       "user",
//         "password":   "pass"
//     }
//  }
var opt_solaris =   require("./config-solaris.json");
var opt_test =      require("./config-test.json");

/*
// mambu.post
describe("mambu-sdk post() tests", function() {

    var mambu_conn = null;

    before("Create connector", function(done) {
        mambu_conn = proxy.create(opt_mambu);
        done();
    });

    describe("POST api/groups", function() {
        var test_id_group;


        it("post without the group name", function(done) {
            var body = {
                group: {}
            };


            mambu_conn.invoke(null, "postGroup", null, null, body, function(err, data) {
                assert(err);
                assert(data);
                done();
            });


        });

        it("post with minimal params", function(done) {
            var body = {
                group: {
                    groupName:"via API"
                }
            };

            mambu_conn.invoke(null, "postGroup", null, null, body, function(err, data) {
                assert(!err);
                assert(data && data.group.id!=null);
                test_id_group = data.group.id;
                done();
            });
        });

        after("remove the created groups", function(done){
            console.log("TBD group deletion")
            done();
        });

    }); // describe("POST api/groups", function() {

    describe("POST /api/savings/{ID}/transactions", function() {
        var test_id_account = "8a85879657978160015799e974321f07",
            test_id_trx;


        it("post trx (SEPA credit) with bad params", function(done) {
            var body = {
                bad: "params"
            };

            mambu_conn.invoke(null, "postTransactionBySavingsId", {id:test_id_account}, null, body, function(err, data) {
                assert(err);
                assert(data);
                done();
            });
        });

        it("post trx (SEPA credit) with minimal params", function(done) {
            var body = {
                type: "WITHDRAWAL",
                amount: 13,
                method: 1,
                customInformation: [
                    {
                        value: "Name recipient",
                        customFieldID: "Recipient_Transactions"
                    },
                    {
                        value: "IBAN",
                        customFieldID: "IBAN_Transactions"
                    },
                    {
                        value: "BIC",
                        customFieldID: "BIC_Transactions"
                    },
                    {
                        value: "Reference",
                        customFieldID: "Reference_Transactions"
                    },
                    {
                        value: "Desc",
                        customFieldID: "Description_Transactions"
                    },
                    {
                        value: "end to end",
                        customFieldID: "End_to_end_id_Transactions"
                    }
                ]
            };

            mambu_conn.invoke(null, "postTransactionBySavingsId", {id:test_id_account}, null, body, function(err, data) {
                assert(!err);
                assert(data && data.encodedKey);
                test_id_trx = data.encodedKey;
                done();
            });
        });

        after("remove the created trxs", function(done){
            console.log("TBD trx deletion")
            done();
        });

    }); // describe("POST api/groups", function() {

});


// mambu.get
describe("mambu get() tests", function() {
    var mambu_conn = null;

    before("Create connector", function(done) {
        mambu_conn = proxy.create(opt_mambu);
        done();
    });

    describe("GET api/groups/{id}", function() {
        it("get with bad group id", function(done) {
            var id = "dsdds";

            mambu_conn.invoke(null, "getGroupById", {id:id}, null, null, function(err, data) {
                assert(err);
                assert(data);
                done();
            });
        });

        it("get OK", function(done) {
            var id = "007432817";

            mambu_conn.invoke(null, "getGroupById", {id:id}, null, null, function(err, data) {
                assert(!err);
                assert(data)
                assert(data.id == "007432817")

                done();
            });
        });
    }); // describe("GET api/groups/{id}/savings", function() {


    describe("GET api/groups/{id}/savings", function() {
       it("get with bad group id", function(done) {
           var id = "dsdds";

           mambu_conn.invoke(null, "getSavingsByGroupId", {id:id}, null, null, function(err, data) {
               assert(err, "Wrong http error code");
               assert(data);
               done();
           });
       });

       it("get OK", function(done) {
           var id = "007432817";

           mambu_conn.invoke(null, "getSavingsByGroupId", {id:id}, null, null, function(err, data) {
               assert(!err);
               assert(data && data.length==1)
               assert(data[0].id == "DEPO837")

               done();
           });
       });
   }); // describe("GET api/groups/{id}/savings", function() {


    describe("GET api/savings/{id}", function() {
        it("get with bad savings id", function(done) {
            var id = "dsdds";

            mambu_conn.invoke(null, "getSavingsByGroupId", {id:id}, null, null, function(err, data) {
                assert(err, "Wrong http error code");
                assert(data);
                done();
            });
        });

        it("get with fullDetails==true", function(done) {
            var id = "007432817";

            mambu_conn.invoke(null, "getSavingsByGroupId", {id:id}, {fullDetails:true}, null, function(err, data) {
                assert(!err);
                assert(data && data.length!=0 && data[0].id == "DEPO837");
                done();
            });
        });

    }); // describe("GET api/groups/{id}/savings", function


    describe("GET api/activities/", function() {

        it("get with no TO date", function(done) {
            var params = {
                from: "2016-01-01"
            };

            mambu_conn.invoke(null, "getActivities", null, params, null, function(err, data) {
                assert(err, "Wrong http error code");
                assert(data);
                done();
            });
        });


        it("get minimal (from and to dates)", function(done) {
            var params = {
                from: "2016-01-01",
                to: "2016-12-31"
            };

            mambu_conn.invoke(null, "getActivities", null, params, null, function(err, data) {
                assert(!err);
                assert(data && data.length > 0, "No data returned");
                done();
            });
        });


    }); // describe("GET api/groups/{id}/savings", function() {


    describe("GET api/accounts{id}/transactions", function() {

        it("get with bad account id", function(done) {
            var bad_id = "bad id";

            mambu_conn.invoke(null, "getTransactionsByAccountId", {id:bad_id}, null, null, function(err, data) {
                assert(err, "Wrong http error code");
                assert(data);
                done();
            });
        });


        it("get all account's transactions", function(done) {
            var id = "8a85879657978160015799e974321f07";

            mambu_conn.invoke(null, "getTransactionsByAccountId", {id:id}, null, null, function(err, data) {
                assert(!err);
                assert(data && data.length > 0, "No data returned");
                done();
            });
        });
    }); // describe("GET api/savings/{id}/transactions", function() {

});
*/

/*
describe("solaris post() tests", function() {
    var solaris_conn = null,
        test_id_account = "a062a8d863e9f436c2cb1f88a6092cf6cacc";

    before("Create connector", function (done) {
        solaris_conn = proxy.create(opt_solaris);
        done();
    });

    describe("POST accounts/{id}/transactions/sepa_credit_transfer", function() {

        it("bad params", function (done) {
            var body = {
                reference: "2",
                recipient_name: "Hans Mustermann",
                // recipient_iban: "DE32110101001000000029",
                recipient_bic: "COBADEFFXXX",
                amount: {
                    value: 130
                },
                description: "Example transaction form api",
                end_to_end_id: ""
            };

            solaris_conn.invoke(null, "postTransaction", {id: test_id_account}, null, body, null, function (err, data) {
                assert(err);
                assert(err.message="Wrong status code. More in details");
                assert(err.details);

                done();
            });
        });

        it("good params", function (done) {
            var body = {
                reference: Math.ceil(Math.random() * 100000000),
                recipient_name: "Hans Mustermann",
                recipient_iban: "DE32110101001000000029",
                recipient_bic: "COBADEFFXXX",
                amount: {
                    value: 130
                },
                description: "Example transaction form api",
                end_to_end_id: ""
            }

            solaris_conn.invoke(null, "postTransaction", {id: test_id_account}, null, body, null, function (err, data) {
                assert(!err);
                assert(data && data.id)
                done();
            });
        });

        it("facta patch", function (done) {
            var id_business='646ce9e716fdd4dc3b537001437b9bf1cbiz',
                now = new Date(),
                body = {
                    fatca_crs_confirmed_at:     now.toISOString(),      // Add a NOW timestamp
                };

            solaris_conn.invoke(null, "patchBusiness", {id_business: id_business}, null, body, null, function (err, data) {

console.log(err)
console.log(data)

                assert(!err);
                assert(data && data.id)
                done();
            });
        });
    });

    describe("POST businesses/{id}/documents", function() {
        it("Good params", function (done) {

            solaris_conn.invoke(null, "sendDocumentByBusiness", {id_business: '3189a6f02afca3c82b0b8ddd3fe0977ccbiz'}, null, {
                document_type: "PICTURE"
            }, {
                file: "./penta.jpg"
            }, 
            function (err, data) {
console.log(err)
                assert(!err);

                assert(data.id);

                done();
            });
        });

    });

});
*/

describe("Testing headers in response", function() {
    var test_conn;

    before("Create connector", function(done) {
        test_conn = proxy.create(opt_test);
        done();
    });

    it("Simple GET", function (done) {

        test_conn.invoke(null, "getPosts", null, null, null, null, function (err, data, res) {

console.log("err=", err);
//console.log("data=", data);
console.log("returned res=", res);



            assert(!err);

            done();
        });
    });


});